import "./App.css";
import Home from "./pages/Home";
import Garten from "./pages/Garten";
import Suche from "./pages/Suche";
import {Routes, Route, useLocation} from "react-router-dom";
import Wunschliste from "./pages/Wunschliste";
import PlantDetails from "./components/PlantDetails";
import Register from "./pages/Register.tsx";
import Login from "./pages/Login.tsx";
import Navbar from "./components/Navbar.tsx";
import NavbarRegistrationAndLogin from "./components/NavbarRegistrationAndLogin.tsx";
import {useEffect, useState} from "react";
import {getCookie} from "./jwt/Cookies.ts";

function App() {
  const [isLoggedIn, setIsLoggedIn] = useState(false);
  const location = useLocation();

  useEffect(() => {
    console.log("check jwt-status")
    const jwtCookie = getCookie("Jwt");
    console.log(jwtCookie)

    if (!jwtCookie) {
      // Wenn der JWT-Cookie nicht vorhanden ist
      setIsLoggedIn(false);
      console.log("Jwt not there")
      return;
    }

    // Der JWT-Cookie ist vorhanden - Überprüfe die Gültigkeit
    // @ts-ignore
    const tokenParts = jwtCookie.split('.');
    if (tokenParts.length !== 3) {
      // Ungültiges JWT-Format (nicht genau 3 Teile)
      setIsLoggedIn(false);
      console.log("Jwt is not valid")
      return;
    }

    const payload = JSON.parse(atob(tokenParts[1]));
    const expirationTime = payload.exp * 1000; //Umwandlung in Millisekunden
    console.log(expirationTime)
    console.log(Date.now())

    // Überprüfe das Ablaufdatum
    if (Date.now() > expirationTime) {
      // JWT ist abgelaufen
      setIsLoggedIn(false);
      console.log("Jwt is expired")
      return;
    }

    // JWT ist vorhanden und gültig
    setIsLoggedIn(true);
  }, [location.pathname]);

  return (
    <div className="App">
      {isLoggedIn ? <Navbar /> : <NavbarRegistrationAndLogin />}
      <Routes>
        <Route path="/" element={<Home />} />
        <Route path="/garten" element={<Garten />} />
        <Route path="/wunschliste" element={<Wunschliste />} />
        <Route path="/suchen" element={<Suche />} />
        <Route path="/pflanze/:plantId" element={<PlantDetails />} />
        <Route path="/api/v1/auth/register" element={<Register />} />
        <Route path="/api/v1/auth/authenticate" element={<Login />} />
      </Routes>

    </div>
  );
}

export default App;
